@@ -487,7 +487,7 @@ extern "C" {
 #define GIALIAS_COLUMN_WAVE             "WAVE"
 #define GIALIAS_COLUMN_WAVE_UNIT        "nm"
 #define GIALIAS_COLUMN_WAVE_TUTYP       "spec:Data.SpectralAxis.Value"
-#define GIALIAS_COLUMN_WAVE_TUCD        "em.wl"
+#define GIALIAS_COLUMN_WAVE_TUCD        "em.wl;obs.atmos"
 #define GIALIAS_COLUMN_WAVE_TCOMM       "Array computed from original WCS"
 #define GIALIAS_COLUMN_FLUX_REDUCED       "FLUX_REDUCED"
 #define GIALIAS_COLUMN_FLUX_REDUCED_UNIT  "adu"
