@@ -42,6 +42,7 @@
 #include <cpl_msg.h>
 
 #include "gimacros.h"
+#include "gierror.h"
 #include "gialias.h"
 #include "giclip.h"
 #include "giarray.h"
@@ -1191,7 +1192,7 @@ _giraffe_extract_summation(const cpl_image* mz, const cpl_image* mvarz,
                  * Sum pixel values along virtual slit.
                  */
 
-                for (y = CX_MAX(ylo, 0); y < yup && y < ny; y++) {
+                for (y = CX_MAX(ylo, 0); (y < yup) && (y < ny); y++) {
 
                     if (!(bpx[x * ny + y] & GIR_M_PIX_SET)) {
 
@@ -1340,7 +1341,7 @@ _giraffe_extract_summation(const cpl_image* mz, const cpl_image* mvarz,
                  * Sum pixel values along virtual slit.
                  */
 
-                for (y = CX_MAX(ylo, 0); y < yup && y < ny; y++) {
+                for (y = CX_MAX(ylo, 0); (y < yup) && (y < ny); y++) {
 
                     cxdouble px = CX_MAX(pixels[x * ny + y], 0.);
 
@@ -2020,9 +2021,9 @@ _giraffe_extract_optimal(const cpl_image* mz, const cpl_image* mzvar,
     _mask = cpl_matrix_get_data(mask);
 
 
-    weights = cpl_matrix_new(ny, 1);
+    weights  = cpl_matrix_new(ny, 1);
 
-    if (mask == NULL) {
+    if (weights == NULL) {
         cpl_matrix_delete(mask);
         mask = NULL;
 
@@ -2563,14 +2564,15 @@ giraffe_extract_spectra(GiExtraction* result, GiImage* image,
     }
 
 
-    if (!cpl_propertylist_has(properties, GIALIAS_CONAD)) {
-        cpl_msg_error(fctid, "Missing detector gain property (%s)! ",
-                      GIALIAS_CONAD);
+    giraffe_error_push();
+
+    conad = giraffe_propertylist_get_conad(properties);
+
+    if (cpl_error_get_code() != CPL_ERROR_NONE) {
         return 1;
     }
-    else {
-        conad = cpl_propertylist_get_double(properties, GIALIAS_CONAD);
-    }
+
+    giraffe_error_pop();
 
 
     if (!cpl_propertylist_has(properties, GIALIAS_BIASERROR)) {
