@@ -1264,7 +1264,7 @@ _giraffe_compute_offsets(const GiImage* spectra, const GiTable* mask,
     cxint xc1 = 0;
     cxint xc2 = 0;
 
-    const cxdouble clight = 299702.547;   /* Vacuum light speed [km/s] */
+    const cxdouble clight = 299702.547;   /* light speed in air [km/s] */
 
     cxdouble cstep = 0.;
     cxdouble wlen0 = 0.;
