@@ -417,7 +417,7 @@ gimasterbias(cpl_parameterlist* config, cpl_frameset* set)
 
     GiStackingConfig* stack_config = NULL;
 
-    GiRecipeInfo info = {(cxchar*)fctid, 1, NULL};
+    GiRecipeInfo info = {(cxchar*)fctid, 1, NULL, config};
 
     GiGroupInfo groups[] = {
         {GIFRAME_BIAS, CPL_FRAME_GROUP_RAW},
